# นี้คือตัวอย่างโปรแกรมสำหรับการเรียน OOP

### วิธีติดตั้ง

เปิด CMD / Terminal

```python
pip install testlearing04UncelShcool
```

### วิธีเล่น

เปิด IDLE ขึ้นมาแล้วพิมพ์...

```python
from testlearing04UncelShcool.stutdentclass import Student, SpecialStudent

print('========== 1 Jan 2021 =========')
student0 = SpecialStudent('Mark Zuckerberg','Bill Gates')
student0.AskEXP()
student0.ShowExp()


student1 = Student('Albert')
print(student1.name)
print(student1.Hello())


print('----------')

student2 = Student('Steve')
print(student2.name)
print(student2.Hello())

print('========== 2 Jan 2021 =========')
print('------- Who are lern coding, get --- (10 exp) ---')
student1.AddEXP(10)  # student1.exp = student.exp +10


print('========== 3 Jan 2021 =========')

student1.name = 'Albert Einst'

print('ตอนนี้ exp ของแต่ละคนได้เท่าไหร่ กันแล้ว')
print(student1.name,student1.exp)
print(student2.name,student2.exp)



print('========== 4 Jan 2021 =========')

print(student1.name,student1.exp)
print(student2.name,student2.exp)


for i in range(5):
	student2.Coding()

student1.ShowExp()
student2.ShowExp()
```



พัฒนาโดย: lidm0707
FB: https://www.facebook.com/UncleEngineer
YouTube: https://www.youtube.com/UncleEngineer


